﻿//
// Copyright (c) 2015, MindFusion LLC - Bulgaria.
//

using System;
using System.Collections.Generic;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Input;


namespace MindFusion.Scheduling.Wpf.Samples.CS.ResourceView
{
	/// <summary>
	/// Interaction logic for ResourceWindow.xaml
	/// </summary>
	public partial class ResourceWindow : Window
	{
		public ResourceWindow(Calendar calendar, Item item)
		{
			InitializeComponent();

			// Initialize contacts combo
			PersonComboBox.Items.Clear();

			foreach (Contact contact in calendar.ItemContacts)
				PersonComboBox.Items.Add(contact.FirstName + " " + contact.LastName);

			_calendar = calendar;
			_item = item;

			// Initialize values from the item
			if (_item != null)
			{
				NameText.Text = _item.HeaderText;
				FromText.Text = _item.StartTime.ToString("MM/dd/yyyy HH:mm");
				ToText.Text = _item.EndTime.ToString("MM/dd/yyyy HH:mm");

				if (_item.Contacts.Count > 0)
				{
					Contact c = _item.Contacts[0];

					for (int i = 0; i < _calendar.ItemContacts.Count; i++)
					{
						if (_calendar.ItemContacts[i] == c)
						{
							PersonComboBox.SelectedIndex = i;
							break;
						}
					}
				}
			}
		}

		private void OkButton_Click(object sender, RoutedEventArgs e)
		{
			if (PersonComboBox.SelectedIndex == -1)
			{
				MessageBox.Show("Select person!");
				return;
			}

			// Accept changes,
			// If new item is created, add the new item to the control
			Item item = _item;

			bool add = false;
			if (item == null)
			{
				item = new Appointment();
				add = true;
			}

			DateTime startDate = item.StartTime;
			if (!DateTime.TryParse(FromText.Text, out startDate))
			{
				MessageBox.Show("Start date is in the wrong format!");
				return;
			}

			DateTime endDate = item.EndTime;
			if (!DateTime.TryParse(ToText.Text, out endDate))
			{
				MessageBox.Show("End date is in the wrong format!");
				return;
			}

			item.HeaderText = NameText.Text;
			item.StartTime = startDate;
			item.EndTime = endDate;

			item.Contacts.Clear();
			item.Contacts.Add(_calendar.ItemContacts[PersonComboBox.SelectedIndex]);

			if (add)
				_calendar.Schedule.Items.Add(item);

			DialogResult = true;
		}

		public void Set(DateTime date, Contact c)
		{
			FromText.Text = date.ToString("MM/dd/yyyy HH:mm");
			ToText.Text = (date + TimeSpan.FromDays(1)).ToString("MM/dd/yyyy HH:mm");

			for (int i = 0; i < _calendar.ItemContacts.Count; i++)
			{
				if (_calendar.ItemContacts[i] == c)
				{
					PersonComboBox.SelectedIndex = i;
					break;
				}
			}
		}

		private void CancelButton_Click(object sender, RoutedEventArgs e)
		{
			DialogResult = false;
		}


		private Calendar _calendar;
		private Item _item;
	}
}
